@@ -1,7 +1,7 @@
 import json
 import snappi
-import snappi_trex.valueoptions
-import snappi_trex.stl_path
+from snappi_trex import valueoptions
+from snappi_trex import stl_path
 from trex.stl.api import *
 
 
@@ -140,12 +140,12 @@ class Api(snappi.Api):
                         layerCnt['Ether'] = layerCnt['Ether']+1 if 'Ether' in layerCnt else 1
 
                         if 'src' in header['ethernet']:
-                            vmCmds += ValueOptions.getMACValueCmds(
+                            vmCmds += valueoptions.getMACValueCmds(
                                 'Ethernet', layerCnt['Ether'], header['ethernet']['src'], 'src', 0
                             )
 
                         if 'dst' in header['ethernet']:
-                            vmCmds += ValueOptions.getMACValueCmds(
+                            vmCmds += valueoptions.getMACValueCmds(
                                 'Ethernet', layerCnt['Ether'], header['ethernet']['dst'], 'dst', 0
                             )
                         
@@ -157,12 +157,12 @@ class Api(snappi.Api):
                         layerCnt['IP'] = layerCnt['IP']+1 if 'IP' in layerCnt else 1
 
                         if 'src' in header['ipv4']:
-                            vmCmds += ValueOptions.getValueCmds(
+                            vmCmds += valueoptions.getValueCmds(
                                 'IP', layerCnt['IP'], header['ipv4']['src'], 32, 'src', 0
                             )
 
                         if 'dst' in header['ipv4']:
-                            vmCmds += ValueOptions.getValueCmds(
+                            vmCmds += valueoptions.getValueCmds(
                                 'IP', layerCnt['IP'], header['ipv4']['dst'], 32, 'dst', 0
                             )
 
@@ -174,12 +174,12 @@ class Api(snappi.Api):
                         layerCnt['UDP'] = layerCnt['UDP']+1 if 'UDP' in layerCnt else 1
 
                         if 'src_port' in header['udp']:
-                            vmCmds += ValueOptions.getValueCmds(
+                            vmCmds += valueoptions.getValueCmds(
                                 'UDP', layerCnt['UDP'], header['udp']['src_port'], 16, 'sport', 0
                             )
 
                         if 'dst_port' in header['udp']:
-                            vmCmds += ValueOptions.getValueCmds(
+                            vmCmds += valueoptions.getValueCmds(
                                 'UDP', layerCnt['UDP'], header['udp']['dst_port'], 16, 'dport', 0
                             )
 
@@ -190,12 +190,12 @@ class Api(snappi.Api):
                         layerCnt['TCP'] = layerCnt['TCP']+1 if 'TCP' in layerCnt else 1
 
                         if 'src_port' in header['tcp']:
-                            vmCmds += ValueOptions.getValueCmds(
+                            vmCmds += valueoptions.getValueCmds(
                                 'TCP', layerCnt['TCP'], header['tcp']['src_port'], 16, 'sport'
                             )
 
                         if 'dst_port' in header['tcp']:
-                            vmCmds += ValueOptions.getValueCmds(
+                            vmCmds += valueoptions.getValueCmds(
                                 'TCP', layerCnt['TCP'], header['tcp']['dst_port'], 16, 'dport'
                             )
 
